@@ -1,11 +1,14 @@
 from __future__ import annotations
 
 import argparse
+import dataclasses as dc
 import json
 import os
+import re
 import sys
 from collections import ChainMap, OrderedDict
 from concurrent.futures import ThreadPoolExecutor
+from fnmatch import fnmatch
 from json import dumps
 from pathlib import Path
 from typing import (
@@ -25,16 +28,14 @@ from resolvelib.structs import DirectedGraph
 from rich.tree import Tree
 
 from pdm import termui
-from pdm.exceptions import PdmArgumentError, PdmUsageError, ProjectError
-from pdm.formats import FORMATS
-from pdm.formats.base import make_array, make_inline_table
+from pdm.exceptions import PdmArgumentError, ProjectError
 from pdm.models.requirements import (
     Requirement,
     filter_requirements_with_extras,
     parse_requirement,
     strip_extras,
 )
-from pdm.models.specifiers import get_specifier
+from pdm.models.specifiers import PySpecSet, get_specifier
 from pdm.utils import (
     comparable_version,
     is_path_relative_to,
@@ -55,28 +56,9 @@ if TYPE_CHECKING:
     from pdm.project import Project
 
 
-class ErrorArgumentParser(argparse.ArgumentParser):
-    """A subclass of argparse.ArgumentParser that raises
-    parsing error rather than exiting.
-
-    This does the same as passing exit_on_error=False on Python 3.9+
-    """
-
-    def _parse_known_args(
-        self, arg_strings: list[str], namespace: argparse.Namespace
-    ) -> tuple[argparse.Namespace, list[str]]:
-        try:
-            return super()._parse_known_args(arg_strings, namespace)
-        except argparse.ArgumentError as e:
-            # We raise a dedicated error to avoid being caught by the caller
-            raise PdmArgumentError(e) from e
-
-
 class PdmFormatter(argparse.RawDescriptionHelpFormatter):
     def start_section(self, heading: str | None) -> None:
-        return super().start_section(
-            termui.style(heading.title() if heading else "", style="warning")
-        )
+        return super().start_section(termui.style(heading.title() if heading else "", style="warning"))
 
     def _format_usage(
         self,
@@ -87,7 +69,9 @@ class PdmFormatter(argparse.RawDescriptionHelpFormatter):
     ) -> str:
         if prefix is None:
             prefix = "Usage: "
-        result = super()._format_usage(usage, actions, groups, prefix)
+        result = super()._format_usage(usage, actions, groups, prefix)  # type: ignore[arg-type]
+        # Remove continuous spaces
+        result = re.sub(r" +", " ", result)
         if prefix:
             return result.replace(prefix, termui.style(prefix, style="warning"))
         return result
@@ -106,16 +90,24 @@ class PdmFormatter(argparse.RawDescriptionHelpFormatter):
 
         # short action name; start on the same line and pad two spaces
         elif len(action_header) <= action_width:
-            tup = self._current_indent, "", action_width, action_header  # type: ignore
-            action_header = "%*s%-*s  " % tup  # type: ignore
+            tup = self._current_indent, "", action_width, action_header  # type: ignore[assignment]
+            action_header = "%*s%-*s  " % tup  # type: ignore[str-format]
             indent_first = 0
 
         # long action name; start on the next line
         else:
-            tup = self._current_indent, "", action_header  # type: ignore
+            tup = self._current_indent, "", action_header
             action_header = "%*s%s\n" % tup
             indent_first = help_position
 
+        # Special format for empty action_header
+        # - No extra indent block
+        # - Help info in the same indent level as subactions
+        if not action_header.strip():
+            action_header = ""
+            help_position = self._current_indent
+            indent_first = self._current_indent
+
         # collect the pieces of the action help
         parts = [termui.style(action_header, style="primary")]
 
@@ -129,37 +121,64 @@ class PdmFormatter(argparse.RawDescriptionHelpFormatter):
 
         # or add a newline if the description doesn't end with one
         elif not action_header.endswith("\n"):
-            parts.append("\n")
+            if action_header:
+                parts.append("\n")
 
+        # cancel out extra indent when action_header is empty
+        if not action_header:
+            self._dedent()
         # if there are any sub-actions, add their help as well
         for subaction in self._iter_indented_subactions(action):
             parts.append(self._format_action(subaction))
+        # cancel out extra dedent when action_header is empty
+        if not action_header:
+            self._indent()
 
         # return a single string
         return self._join_parts(parts)
 
 
+class ArgumentParser(argparse.ArgumentParser):
+    """A standard argument parser but with title-cased help."""
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        kwargs["formatter_class"] = PdmFormatter
+        kwargs["add_help"] = False
+        super().__init__(*args, **kwargs)
+        self.add_argument(
+            "-h", "--help", action="help", default=argparse.SUPPRESS, help="Show this help message and exit."
+        )
+        self._optionals.title = "options"
+
+
+class ErrorArgumentParser(ArgumentParser):
+    """A subclass of argparse.ArgumentParser that raises
+    parsing error rather than exiting.
+
+    This does the same as passing exit_on_error=False on Python 3.9+
+    """
+
+    def _parse_known_args(
+        self, arg_strings: list[str], namespace: argparse.Namespace
+    ) -> tuple[argparse.Namespace, list[str]]:
+        try:
+            return super()._parse_known_args(arg_strings, namespace)
+        except argparse.ArgumentError as e:
+            # We raise a dedicated error to avoid being caught by the caller
+            raise PdmArgumentError(e) from e
+
+
+@dc.dataclass(frozen=True)
 class Package:
     """An internal class for the convenience of dependency graph building."""
 
-    def __init__(
-        self, name: str, version: str | None, requirements: dict[str, Requirement]
-    ) -> None:
-        self.name = name
-        self.version = version  # if version is None, the dist is not installed.
-        self.requirements = requirements
-
-    def __hash__(self) -> int:
-        return hash(self.name)
+    name: str = dc.field(hash=True, compare=True)
+    version: str | None = dc.field(compare=False)
+    requirements: dict[str, Requirement] = dc.field(compare=False)
 
     def __repr__(self) -> str:
         return f"<Package {self.name}=={self.version}>"
 
-    def __eq__(self, value: object) -> bool:
-        if not isinstance(value, Package):
-            return False
-        return self.name == value.name
-
 
 def build_dependency_graph(
     working_set: Mapping[str, im.Distribution],
@@ -238,7 +257,7 @@ def add_package_to_tree(
     root: Tree,
     graph: DirectedGraph,
     package: Package,
-    required: str = "",
+    required: list[str],
     visited: frozenset[str] = frozenset(),
 ) -> None:
     """Format one package.
@@ -253,21 +272,20 @@ def add_package_to_tree(
         if not package.version
         else f"[error]{package.version}[/]"
         if required
-        and required not in ("Any", "This project")
-        and not SpecifierSet(required).contains(package.version)
+        and not any(s in ("Any", "This project") or SpecifierSet(s).contains(package.version) for s in required)
         else f"[warning]{package.version}[/]"
     )
     # escape deps with extras
     name = package.name.replace("[", r"\[") if "[" in package.name else package.name
     if package.name in visited:
         version = r"[error]\[circular][/]"
-    required = f"[ required: {required} ]" if required else "[ Not required ]"
-    node = root.add(f"[req]{name}[/] {version} {required}")
+    req_str = f"[ required: {'&&'.join(required)} ]" if required else "[ Not required ]"
+    node = root.add(f"[req]{name}[/] {version} {req_str}")
     if package.name in visited:
         return
     children = sorted(graph.iter_children(package), key=lambda p: p.name)
     for child in children:
-        required = specifier_from_requirement(package.requirements[child.name])
+        required = [specifier_from_requirement(package.requirements[child.name])]
         add_package_to_tree(node, graph, child, required, visited | {package.name})
 
 
@@ -280,11 +298,7 @@ def add_package_to_reverse_tree(
     visited: frozenset[str] = frozenset(),
 ) -> None:
     """Format one package for output reverse dependency graph."""
-    version = (
-        "[error][ not installed ][/]"
-        if not package.version
-        else f"[warning]{package.version}[/]"
-    )
+    version = "[error][ not installed ][/]" if not package.version else f"[warning]{package.version}[/]"
     if package.name in visited:
         version = r"[error]\[circular][/]"
     requires = (
@@ -302,51 +316,71 @@ def add_package_to_reverse_tree(
 
     if package.name in visited:
         return
-    parents: list[Package] = sorted(
-        filter(None, graph.iter_parents(package)), key=lambda p: p.name
-    )
+    parents: list[Package] = sorted(filter(None, graph.iter_parents(package)), key=lambda p: p.name)
     for parent in parents:
         requires = specifier_from_requirement(parent.requirements[package.name])
-        add_package_to_reverse_tree(
-            node, graph, parent, package, requires, visited=visited | {package.name}
-        )
+        add_package_to_reverse_tree(node, graph, parent, package, requires, visited=visited | {package.name})
     return
 
 
 def package_is_project(package: Package, project: Project) -> bool:
-    return (
-        not project.environment.is_global
-        and project.name is not None
-        and package.name == normalize_name(project.name)
-    )
+    return project.name is not None and package.name == normalize_name(project.name)
 
 
-def _format_forward_dependency_graph(project: Project, graph: DirectedGraph) -> Tree:
+def _format_forward_dependency_graph(
+    project: Project, graph: DirectedGraph[Package | None], patterns: list[str]
+) -> Tree:
     """Format dependency graph for output."""
     root = Tree("Dependencies", hide_root=True)
+
+    def find_package_to_add(package: Package) -> Package | None:
+        if not patterns:
+            return package
+        to_check = [package]
+        while to_check:
+            package = to_check.pop(0)
+            if package and package_match_patterns(package, patterns):
+                return package
+            to_check.extend(graph.iter_children(package))
+        return None
+
     all_dependencies = ChainMap(*project.all_dependencies.values())
-    top_level_dependencies = sorted(graph.iter_children(None), key=lambda p: p.name)
-    for package in top_level_dependencies:
-        if package.name in all_dependencies:
-            required = specifier_from_requirement(all_dependencies[package.name])
-        elif package_is_project(package, project):
-            required = "This project"
-        else:
-            required = ""
-        add_package_to_tree(root, graph, package, required)
+    top_level_dependencies = {find_package_to_add(node) for node in graph.iter_children(None) if node}
+    for package in sorted((node for node in top_level_dependencies if node), key=lambda p: p.name):
+        required: set[str] = set()
+        for parent in graph.iter_parents(package):
+            if parent:
+                r = specifier_from_requirement(parent.requirements[package.name])
+            elif package.name in all_dependencies:
+                r = specifier_from_requirement(all_dependencies[package.name])
+            elif package_is_project(package, project):
+                r = "This project"
+            else:
+                continue
+            required.add(r)
+        add_package_to_tree(root, graph, package, sorted(required))
     return root
 
 
 def _format_reverse_dependency_graph(
-    project: Project, graph: DirectedGraph[Package | None]
+    project: Project, graph: DirectedGraph[Package | None], patterns: list[str]
 ) -> Tree:
     """Format reverse dependency graph for output."""
+
+    def find_package_to_add(package: Package) -> Package | None:
+        if not patterns:
+            return package
+        to_check = [package]
+        while to_check:
+            package = to_check.pop(0)
+            if package and package_match_patterns(package, patterns):
+                return package
+            to_check.extend(graph.iter_parents(package))
+        return None
+
     root = Tree("Dependencies", hide_root=True)
-    leaf_nodes = sorted(
-        (node for node in graph if not list(graph.iter_children(node)) and node),
-        key=lambda p: p.name,
-    )
-    for package in leaf_nodes:
+    leaf_nodes = {find_package_to_add(node) for node in graph if not list(graph.iter_children(node)) and node}
+    for package in sorted((node for node in leaf_nodes if node), key=lambda p: p.name):
         if not package:
             continue
         add_package_to_reverse_tree(root, graph, package)
@@ -360,30 +394,29 @@ def build_forward_dependency_json_subtree(
     required_by: Package | None = None,
     visited: frozenset[str] = frozenset(),
 ) -> dict:
-    if not package_is_project(root, project):
-        requirements = (
-            required_by.requirements
-            if required_by
-            else ChainMap(*project.all_dependencies.values())
-        )
-        if root.name in requirements:
-            required = specifier_from_requirement(requirements[root.name])
+    required: set[str] = set()
+    for parent in graph.iter_parents(root):
+        if parent:
+            r = specifier_from_requirement(parent.requirements[root.name])
+        elif not package_is_project(root, project):
+            requirements = required_by.requirements if required_by else ChainMap(*project.all_dependencies.values())
+            if root.name in requirements:
+                r = specifier_from_requirement(requirements[root.name])
+            else:
+                continue
         else:
-            required = "Not required"
-    else:
-        required = "This project"
+            r = "This project"
+        required.add(r)
 
     children = graph.iter_children(root) if root.name not in visited else []
 
     return OrderedDict(
         package=root.name,
         version=root.version,
-        required=required,
+        required="&&".join(sorted(required)),
         dependencies=sorted(
             (
-                build_forward_dependency_json_subtree(
-                    p, project, graph, root, visited | {root.name}
-                )
+                build_forward_dependency_json_subtree(p, project, graph, root, visited | {root.name})
                 for p in children
                 if p
             ),
@@ -403,14 +436,10 @@ def build_reverse_dependency_json_subtree(
     return OrderedDict(
         package=root.name,
         version=root.version,
-        requires=specifier_from_requirement(root.requirements[requires.name])
-        if requires
-        else None,
+        requires=specifier_from_requirement(root.requirements[requires.name]) if requires else None,
         dependents=sorted(
             (
-                build_reverse_dependency_json_subtree(
-                    p, project, graph, root, visited | {root.name}
-                )
+                build_reverse_dependency_json_subtree(p, project, graph, root, visited | {root.name})
                 for p in parents
                 if p
             ),
@@ -419,21 +448,38 @@ def build_reverse_dependency_json_subtree(
     )
 
 
+def package_match_patterns(package: Package, patterns: list[str]) -> bool:
+    return not patterns or any(fnmatch(package.name, pattern) for pattern in patterns)
+
+
 def build_dependency_json_tree(
-    project: Project, graph: DirectedGraph[Package | None], reverse: bool
+    project: Project, graph: DirectedGraph[Package | None], reverse: bool, patterns: list[str]
 ) -> list[dict]:
+    def find_package_to_add(package: Package) -> Package | None:
+        if not patterns:
+            return package
+        to_check = [package]
+        while to_check:
+            package = to_check.pop(0)
+            if package and package_match_patterns(package, patterns):
+                return package
+            if reverse:
+                to_check.extend(graph.iter_parents(package))
+            else:
+                to_check.extend(graph.iter_children(package))
+        return None
+
+    top_level_packages: Iterable[Package | None]
     if reverse:
-        top_level_packages = filter(
-            lambda n: not list(graph.iter_children(n)), graph
-        )  # leaf nodes
+        top_level_packages = filter(lambda n: not list(graph.iter_children(n)), graph)  # leaf nodes
         build_dependency_json_subtree: Callable = build_reverse_dependency_json_subtree
     else:
         top_level_packages = graph.iter_children(None)  # root nodes
         build_dependency_json_subtree = build_forward_dependency_json_subtree
+    top_level_packages = {find_package_to_add(node) for node in top_level_packages if node}
     return [
         build_dependency_json_subtree(p, project, graph)
-        for p in sorted(top_level_packages, key=lambda p: p.name if p else "")
-        if p
+        for p in sorted((node for node in top_level_packages if node), key=lambda p: p.name)
     ]
 
 
@@ -442,21 +488,24 @@ def show_dependency_graph(
     graph: DirectedGraph[Package | None],
     reverse: bool = False,
     json: bool = False,
+    patterns: list[str] | None = None,
 ) -> None:
     echo = project.core.ui.echo
+    if patterns is None:
+        patterns = []
     if json:
         echo(
             dumps(
-                build_dependency_json_tree(project, graph, reverse),
+                build_dependency_json_tree(project, graph, reverse, patterns),
                 indent=2,
             )
         )
         return
 
     if reverse:
-        tree = _format_reverse_dependency_graph(project, graph)
+        tree = _format_reverse_dependency_graph(project, graph, patterns)
     else:
-        tree = _format_forward_dependency_graph(project, graph)
+        tree = _format_forward_dependency_graph(project, graph, patterns)
     echo(tree)
 
 
@@ -464,42 +513,49 @@ def format_lockfile(
     project: Project,
     mapping: dict[str, Candidate],
     fetched_dependencies: dict[tuple[str, str | None], list[Requirement]],
+    groups: list[str] | None = None,
+    cross_platform: bool | None = None,
+    static_urls: bool | None = None,
 ) -> dict:
     """Format lock file from a dict of resolved candidates, a mapping of dependencies
     and a collection of package summaries.
     """
+    from pdm.formats.base import make_array, make_inline_table
 
     packages = tomlkit.aot()
-    file_hashes = tomlkit.table()
-    for k, v in sorted(mapping.items()):
+    for _k, v in sorted(mapping.items()):
         base = tomlkit.table()
-        base.update(v.as_lockfile_entry(project.root))  # type: ignore
+        base.update(v.as_lockfile_entry(project.root))
         base.add("summary", v.summary or "")
-        deps = make_array(
-            sorted(r.as_line() for r in fetched_dependencies[v.dep_key]), True
-        )
+        deps = make_array(sorted(r.as_line() for r in fetched_dependencies[v.dep_key]), True)
         if len(deps) > 0:
             base.add("dependencies", deps)
-        packages.append(base)  # type: ignore
         if v.hashes:
-            key = f"{strip_extras(k)[0]} {v.version}"
-            if key in file_hashes:
-                continue
-            array = tomlkit.array().multiline(True)
-            for link, hash_value in sorted(
-                v.hashes.items(), key=lambda l_h: (l_h[0].url_without_fragment, l_h[1])
-            ):
-                inline = make_inline_table(
-                    {"url": link.url_without_fragment, "hash": hash_value}
-                )
-                array.append(inline)  # type: ignore
-            if array:
-                file_hashes.add(key, array)
+            collected = {}
+            for item in v.hashes:
+                if static_urls:
+                    row = {"url": item["url"], "hash": item["hash"]}
+                else:
+                    row = {"file": item["file"], "hash": item["hash"]}
+                inline = make_inline_table(row)
+                # deduplicate and sort
+                collected[tuple(row.values())] = inline
+            if collected:
+                base.add("files", make_array([collected[k] for k in sorted(collected)], True))
+        packages.append(base)
     doc = tomlkit.document()
-    doc.add("package", packages)  # type: ignore
     metadata = tomlkit.table()
-    metadata.add("files", file_hashes)
-    doc.add("metadata", metadata)  # type: ignore
+    if groups is None:
+        groups = list(project.iter_groups())
+    metadata.update(
+        {
+            "groups": sorted(groups, key=lambda k: k != "default"),
+            "cross_platform": cross_platform if cross_platform is not None else project.lockfile.cross_platform,
+            "static_urls": static_urls if static_urls is not None else project.lockfile.static_urls,
+        }
+    )
+    doc.add("metadata", metadata)
+    doc.add("package", packages)
     return cast(dict, doc)
 
 
@@ -523,41 +579,30 @@ def save_version_specifiers(
         for name, r in reqs.items():
             if r.is_named and not r.specifier:
                 if save_strategy == "exact":
-                    r.specifier = get_specifier(
-                        f"=={candidate_version(resolved[name])}"
-                    )
+                    r.specifier = get_specifier(f"=={candidate_version(resolved[name])}")
                 elif save_strategy == "compatible":
                     version = candidate_version(resolved[name])
                     if version.is_prerelease or version.is_devrelease:
                         r.specifier = get_specifier(f">={version},<{version.major + 1}")
                     else:
-                        r.specifier = get_specifier(
-                            f"~={version.major}.{version.minor}"
-                        )
+                        r.specifier = get_specifier(f"~={version.major}.{version.minor}")
                 elif save_strategy == "minimum":
-                    r.specifier = get_specifier(
-                        f">={candidate_version(resolved[name])}"
-                    )
+                    r.specifier = get_specifier(f">={candidate_version(resolved[name])}")
 
 
 def check_project_file(project: Project) -> None:
     """Check the existence of the project file and throws an error on failure."""
     if not project.pyproject.is_valid:
         raise ProjectError(
-            "The pyproject.toml has not been initialized yet. You can do this "
-            "by running [success]`pdm init`[/]."
+            "The pyproject.toml has not been initialized yet. You can do this by running [success]`pdm init`[/]."
         ) from None
 
 
 def find_importable_files(project: Project) -> Iterable[tuple[str, Path]]:
     """Find all possible files that can be imported"""
-    for filename in (
-        "Pipfile",
-        "pyproject.toml",
-        "requirements.in",
-        "requirements.txt",
-        "setup.py",
-    ):
+    from pdm.formats import FORMATS
+
+    for filename in ("Pipfile", "pyproject.toml", "requirements.in", "requirements.txt", "setup.py", "setup.cfg"):
         project_file = project.root / filename
         if not project_file.exists():
             continue
@@ -584,7 +629,7 @@ def set_env_in_reg(env_name: str, value: str) -> None:
                     return
             except FileNotFoundError:
                 paths, type_ = [], winreg.REG_EXPAND_SZ
-            new_value = os.pathsep.join([value] + paths)
+            new_value = os.pathsep.join([value, *paths])
             winreg.SetValueEx(env_key, env_name, 0, type_, new_value)
 
 
@@ -594,27 +639,29 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
     causes: list[RequirementInformation] = err.causes
     info_lines: set[str] = set()
     if all(isinstance(cause.requirement, PythonRequirement) for cause in causes):
-        project_requires = next(
-            cause.requirement for cause in causes if cause.parent is None
-        )
+        project_requires: PythonRequirement = next(cause.requirement for cause in causes if cause.parent is None)
+        pyspec = cast(PySpecSet, project_requires.specifier)
         conflicting = [
             cause
             for cause in causes
-            if cause.parent is not None
-            and not cause.requirement.specifier.is_superset(project_requires.specifier)
+            if cause.parent is not None and not cause.requirement.specifier.is_superset(pyspec)
         ]
         result = [
             "Unable to find a resolution because the following dependencies don't work "
-            "on all Python versions defined by the project's `requires-python`: "
-            f"[success]{str(project_requires.specifier)}[/]."
+            "on all Python versions in the range of the project's `requires-python`: "
+            f"[success]{pyspec}[/]."
         ]
         for req, parent in conflicting:
-            info_lines.add(f"  {req.as_line()} (from {repr(parent)})")
+            pyspec &= req.specifier
+            info_lines.add(f"  {req.as_line()} (from {parent!r})")
         result.extend(sorted(info_lines))
-        result.append(
-            "To fix this, you can change the value of `requires-python` "
-            "in pyproject.toml."
-        )
+        if pyspec.is_impossible:
+            result.append("Consider changing the version specifiers of the dependencies to be compatible")
+        else:
+            result.append(
+                "A possible solution is to change the value of `requires-python` "
+                f"in pyproject.toml to [success]{pyspec}[/]."
+            )
         return "\n".join(result)
 
     if len(causes) == 1:
@@ -640,42 +687,7 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
     return "\n".join(result)
 
 
-def translate_groups(
-    project: Project, default: bool, dev: bool, groups: Iterable[str]
-) -> list[str]:
-    """Translate default, dev and groups containing ":all" into a list of groups"""
-    optional_groups = set(project.pyproject.metadata.get("optional-dependencies", {}))
-    dev_groups = set(project.pyproject.settings.get("dev-dependencies", {}))
-    groups_set = set(groups)
-    if dev is None:
-        dev = True
-    if groups_set & dev_groups:
-        if not dev:
-            raise PdmUsageError(
-                "--prod is not allowed with dev groups and should be left"
-            )
-    elif dev:
-        groups_set.update(dev_groups)
-    if ":all" in groups:
-        groups_set.discard(":all")
-        groups_set.update(optional_groups)
-    if default:
-        groups_set.add("default")
-    # Sorts the result in ascending order instead of in random order
-    # to make this function pure
-    invalid_groups = groups_set - set(project.iter_groups())
-    if invalid_groups:
-        project.core.ui.echo(
-            f"[d]Ignoring non-existing groups: [success]{', '.join(invalid_groups)}[/]",
-            err=True,
-        )
-        groups_set -= invalid_groups
-    return sorted(groups_set)
-
-
-def merge_dictionary(
-    target: MutableMapping[Any, Any], input: Mapping[Any, Any]
-) -> None:
+def merge_dictionary(target: MutableMapping[Any, Any], input: Mapping[Any, Any], append_array: bool = True) -> None:
     """Merge the input dict with the target while preserving the existing values
     properly. This will update the target dictionary in place.
     List values will be extended, but only if the value is not already in the list.
@@ -683,10 +695,12 @@ def merge_dictionary(
     for key, value in input.items():
         if key not in target:
             target[key] = value
-        elif isinstance(value, dict):
-            target[key].update(value)
-        elif isinstance(value, list):
-            target[key].extend([x for x in value if x not in target[key]])
+        elif isinstance(target[key], dict):
+            merge_dictionary(target[key], value, append_array=append_array)
+        elif isinstance(target[key], list) and append_array:
+            target[key].extend(x for x in value if x not in target[key])
+            if hasattr(target[key], "multiline"):
+                target[key].multiline(True)  # type: ignore[attr-defined]
         else:
             target[key] = value
 
@@ -695,7 +709,6 @@ def fetch_hashes(repository: BaseRepository, mapping: Mapping[str, Candidate]) -
     """Fetch hashes for candidates in parallel"""
 
     def do_fetch(candidate: Candidate) -> None:
-        termui.logger.info("Fetching hashes for %s", candidate)
         candidate.hashes = repository.get_hashes(candidate)
 
     with ThreadPoolExecutor() as executor:
@@ -711,9 +724,7 @@ def is_homebrew_installation() -> bool:
 
 
 def is_scoop_installation() -> bool:
-    return os.name == "nt" and is_path_relative_to(
-        sys.prefix, Path.home() / "scoop/apps/pdm"
-    )
+    return os.name == "nt" and is_path_relative_to(sys.prefix, Path.home() / "scoop/apps/pdm")
 
 
 def get_dist_location(dist: Distribution) -> str:
@@ -730,7 +741,7 @@ def get_dist_location(dist: Distribution) -> str:
 
 
 def get_pep582_path(project: Project) -> str:
-    import importlib.resources
+    from pdm.compat import resources_open_binary
 
     script_dir = Path(__file__).parent.parent / "pep582"
     if script_dir.exists():
@@ -740,6 +751,25 @@ def get_pep582_path(project: Project) -> str:
     if script_dir.joinpath("sitecustomize.py").exists():
         return str(script_dir)
     script_dir.mkdir(parents=True, exist_ok=True)
-    with importlib.resources.open_binary("pdm.pep582", "sitecustomize.py") as f:
+    with resources_open_binary("pdm.pep582", "sitecustomize.py") as f:
         script_dir.joinpath("sitecustomize.py").write_bytes(f.read())
     return str(script_dir)
+
+
+def use_venv(project: Project, name: str) -> None:
+    from pdm.cli.commands.venv.utils import get_venv_with_name
+    from pdm.environments import PythonEnvironment
+
+    venv = get_venv_with_name(project, cast(str, name))
+    project.core.ui.echo(
+        f"In virtual environment: [success]{venv.root}[/]", err=True, style="info", verbosity=termui.Verbosity.DETAIL
+    )
+    project.environment = PythonEnvironment(project, python=str(venv.interpreter))
+
+
+def populate_requirement_names(req_mapping: dict[str, Requirement]) -> None:
+    # Update the requirement key if the name changed.
+    for key, req in list(req_mapping.items()):
+        if key and key.startswith(":empty:"):
+            req_mapping[req.identify()] = req
+            del req_mapping[key]
