@@ -5,6 +5,7 @@ import functools
 import inspect
 import json
 import os
+import posixpath
 import re
 import secrets
 import urllib.parse as urlparse
@@ -17,24 +18,27 @@ from packaging.requirements import InvalidRequirement
 from packaging.requirements import Requirement as PackageRequirement
 from packaging.specifiers import SpecifierSet
 from packaging.utils import parse_sdist_filename, parse_wheel_filename
-from packaging.version import parse as parse_version
-from unearth import Link
 
 from pdm.compat import Distribution
 from pdm.exceptions import ExtrasWarning, RequirementError
 from pdm.models.backends import BuildBackend, get_relative_path
 from pdm.models.markers import Marker, get_marker, split_marker_extras
 from pdm.models.setup import Setup
-from pdm.models.specifiers import PySpecSet, get_specifier
+from pdm.models.specifiers import PySpecSet, fix_legacy_specifier, get_specifier
 from pdm.utils import (
+    PACKAGING_22,
     add_ssh_scheme_to_git_uri,
+    comparable_version,
     normalize_name,
     path_to_url,
+    path_without_fragments,
     url_to_path,
     url_without_fragments,
 )
 
 if TYPE_CHECKING:
+    from unearth import Link
+
     from pdm._types import RequirementDict
 
 
@@ -82,9 +86,7 @@ class Requirement:
     prerelease: bool = False
 
     def __post_init__(self) -> None:
-        self.requires_python = (
-            self.marker.split_pyspec()[1] if self.marker else PySpecSet()
-        )
+        self.requires_python = self.marker.split_pyspec()[1] if self.marker else PySpecSet()
 
     @property
     def project_name(self) -> str | None:
@@ -109,11 +111,7 @@ class Requirement:
         """Return a new requirement with the given pinned version."""
         if self.is_pinned or not other_version:
             return self
-        version = parse_version(other_version)
-        normalized = str(version)
-        if version.local:
-            # Remove the local part to accept wider range of prereleases.
-            normalized = normalized.rsplit("+", 1)[0]
+        normalized = comparable_version(other_version)
         return dataclasses.replace(self, specifier=get_specifier(f"=={normalized}"))
 
     def _hash_key(self) -> tuple:
@@ -149,19 +147,10 @@ class Requirement:
             except InvalidMarker as e:
                 raise RequirementError("Invalid marker: %s" % str(e)) from None
         if "extras" in kwargs and isinstance(kwargs["extras"], str):
-            kwargs["extras"] = tuple(
-                e.strip() for e in kwargs["extras"][1:-1].split(",")
-            )
-        version = kwargs.pop("version", None)
-        if version:
-            kwargs["specifier"] = get_specifier(version)
-        return cls(
-            **{
-                k: v
-                for k, v in kwargs.items()
-                if k in inspect.signature(cls).parameters
-            }
-        )
+            kwargs["extras"] = tuple(e.strip() for e in kwargs["extras"][1:-1].split(","))
+        version = kwargs.pop("version", "")
+        kwargs["specifier"] = get_specifier(version)
+        return cls(**{k: v for k, v in kwargs.items() if k in inspect.signature(cls).parameters})
 
     @classmethod
     def from_dist(cls, dist: Distribution) -> Requirement:
@@ -183,9 +172,7 @@ class Requirement:
                 )
                 return VcsRequirement.create(**data)
             return FileRequirement.create(**data)
-        return NamedRequirement.create(
-            name=dist.metadata["Name"], version=f"=={dist.version}"
-        )
+        return NamedRequirement.create(name=dist.metadata["Name"], version=f"=={dist.version}")
 
     @classmethod
     def from_req_dict(cls, name: str, req_dict: RequirementDict) -> Requirement:
@@ -227,6 +214,8 @@ class Requirement:
 
     @classmethod
     def from_pkg_requirement(cls, req: PackageRequirement) -> Requirement:
+        from unearth import Link
+
         kwargs = {
             "name": req.name,
             "extras": req.extras,
@@ -236,13 +225,13 @@ class Requirement:
         if getattr(req, "url", None):
             link = Link(cast(str, req.url))
             klass = VcsRequirement if link.is_vcs else FileRequirement
-            return klass(url=req.url, **kwargs)  # type: ignore
+            return klass(url=req.url, **kwargs)
         else:
-            return NamedRequirement(**kwargs)  # type: ignore
+            return NamedRequirement(**kwargs)  # type: ignore[arg-type]
 
     def _format_marker(self) -> str:
         if self.marker:
-            return f"; {str(self.marker)}"
+            return f"; {self.marker!s}"
         return ""
 
 
@@ -250,7 +239,7 @@ class Requirement:
 class NamedRequirement(Requirement):
     def as_line(self) -> str:
         extras = f"[{','.join(sorted(self.extras))}]" if self.extras else ""
-        return f"{self.project_name}{extras}{self.specifier}{self._format_marker()}"
+        return f"{self.project_name}{extras}{self.specifier or ''}{self._format_marker()}"
 
 
 @dataclasses.dataclass(eq=False)
@@ -266,20 +255,56 @@ class FileRequirement(Requirement):
             self._check_installable()
 
     def _hash_key(self) -> tuple:
-        return super()._hash_key() + (self.url, self.editable)
+        return (*super()._hash_key(), self.get_full_url(), self.editable)
+
+    def guess_name(self) -> str | None:
+        filename = os.path.basename(urlparse.unquote(url_without_fragments(self.url))).rsplit("@", 1)[0]
+        if self.is_vcs:
+            if self.vcs == "git":  # type: ignore[attr-defined]
+                name = filename
+                if name.endswith(".git"):
+                    name = name[:-4]
+                return name
+            elif self.vcs == "hg":  # type: ignore[attr-defined]
+                return filename
+            else:  # svn and bzr
+                name, in_branch, _ = filename.rpartition("/branches/")
+                if not in_branch and name.endswith("/trunk"):
+                    return name[:-6]
+                return name
+        elif filename.endswith(".whl"):
+            return parse_wheel_filename(filename)[0]
+        else:
+            try:
+                return parse_sdist_filename(filename)[0]
+            except ValueError:
+                match = _egg_info_re.match(filename)
+                # Filename is like `<name>-<version>.tar.gz`, where name will be
+                # extracted and version will be left to be determined from
+                # the metadata.
+                if match:
+                    return match.group(1)
+        return None
 
     @classmethod
     def create(cls: type[T], **kwargs: Any) -> T:
         if kwargs.get("path"):
             kwargs["path"] = Path(kwargs["path"])
-        return super().create(**kwargs)  # type: ignore
+        return super().create(**kwargs)
 
     @property
     def str_path(self) -> str | None:
         if not self.path:
             return None
-        result = self.path.as_posix()
-        if not self.path.is_absolute() and not result.startswith(("./", "../")):
+        if self.path.is_absolute():
+            try:
+                result = self.path.relative_to(Path.cwd()).as_posix()
+            except ValueError:
+                return self.path.as_posix()
+        else:
+            result = self.path.as_posix()
+        result = posixpath.normpath(result)
+        if not result.startswith(("./", "../")):
             result = "./" + result
         if result.startswith("./../"):
             result = result[2:]
@@ -292,11 +317,11 @@ class FileRequirement(Requirement):
             path = get_relative_path(self.url)
             if path is None:
                 try:
-                    self.path = Path(url_to_path(self.url))
+                    self.path = path_without_fragments(url_to_path(self.url))
                 except AssertionError:
                     pass
             else:
-                self.path = Path(path)
+                self.path = path_without_fragments(path)
         if self.url:
             self._parse_name_from_url()
 
@@ -305,8 +330,11 @@ class FileRequirement(Requirement):
         if self.path is None or self.path.is_absolute():
             return
         # self.path is relative
-        self.path = Path(os.path.relpath(self.path, backend.root))
-        self.url = backend.relative_path_to_url(self.path.as_posix())
+        self.path = path_without_fragments(os.path.relpath(self.path, backend.root))
+        path = self.path.as_posix()
+        if path == ".":
+            path = ""
+        self.url = backend.relative_path_to_url(path)
 
     @property
     def is_local(self) -> bool:
@@ -317,6 +345,8 @@ class FileRequirement(Requirement):
         return self.is_local and cast(Path, self.path).is_dir()
 
     def as_file_link(self) -> Link:
+        from unearth import Link
+
         url = self.get_full_url()
         # only subdirectory is useful in a file link
         if self.subdirectory:
@@ -328,11 +358,7 @@ class FileRequirement(Requirement):
 
     def as_line(self) -> str:
         project_name = f"{self.project_name}" if self.project_name else ""
-        extras = (
-            f"[{','.join(sorted(self.extras))}]"
-            if self.extras and self.project_name
-            else ""
-        )
+        extras = f"[{','.join(sorted(self.extras))}]" if self.extras and self.project_name else ""
         marker = self._format_marker()
         if marker:
             marker = f" {marker}"
@@ -359,28 +385,11 @@ class FileRequirement(Requirement):
             if not self.extras:
                 self.extras = extras
         if not self.name and not self.is_vcs:
-            filename = os.path.basename(
-                urlparse.unquote(url_without_fragments(self.url))
-            )
-            if filename.endswith(".whl"):
-                self.name, *_ = parse_wheel_filename(filename)
-            else:
-                try:
-                    self.name, *_ = parse_sdist_filename(filename)
-                except ValueError:
-                    match = _egg_info_re.match(filename)
-                    # Filename is like `<name>-<version>.tar.gz`, where name will be
-                    # extracted and version will be left to be determined from
-                    # the metadata.
-                    if match:
-                        self.name = match.group(1)
+            self.name = self.guess_name()
 
     def _check_installable(self) -> None:
         assert self.path
-        if not (
-            self.path.joinpath("setup.py").exists()
-            or self.path.joinpath("pyproject.toml").exists()
-        ):
+        if not (self.path.joinpath("setup.py").exists() or self.path.joinpath("pyproject.toml").exists()):
             raise RequirementError(f"The local path '{self.path}' is not installable.")
         result = Setup.from_directory(self.path.absolute())
         if result.name:
@@ -422,7 +431,7 @@ class VcsRequirement(FileRequirement):
             path, ref = parsed.path.split("@", 1)
         repo = urlparse.urlunparse(parsed._replace(path=path, fragment=""))
         self.url = f"{vcs}+{repo}"
-        self.repo, self.ref = repo, ref  # type: ignore
+        self.repo, self.ref = repo, ref
 
 
 def filter_requirements_with_extras(
@@ -435,6 +444,7 @@ def filter_requirements_with_extras(
     If extras are given, return those with matching extra markers.
     Otherwise, return those without extra markers.
     """
+    extras = [normalize_name(e) for e in extras]
     result: list[str] = []
     extras_in_meta: set[str] = set()
     for req in requirement_lines:
@@ -446,23 +456,28 @@ def filter_requirements_with_extras(
                 _r.marker = Marker(rest) if rest else None
         else:
             req_extras = set()
-        if (
-            req_extras
-            and not req_extras.isdisjoint(extras)
-            or not req_extras
-            and (include_default or not extras)
-        ):
+        if req_extras and not req_extras.isdisjoint(extras) or not req_extras and (include_default or not extras):
             result.append(_r.as_line())
 
     extras_not_found = [e for e in extras if e not in extras_in_meta]
     if extras_not_found:
-        warnings.warn(ExtrasWarning(project_name, extras_not_found))
+        warnings.warn(ExtrasWarning(project_name, extras_not_found), stacklevel=2)
 
     return result
 
 
-def parse_requirement(line: str, editable: bool = False) -> Requirement:
+def parse_as_pkg_requirement(line: str) -> PackageRequirement:
+    """Parse a requirement line as packaging.requirement.Requirement"""
+    try:
+        return PackageRequirement(line)
+    except InvalidRequirement:
+        if not PACKAGING_22:  # We can't do anything, reraise the error.
+            raise
+        new_line = fix_legacy_specifier(line)
+        return PackageRequirement(new_line)
 
+
+def parse_requirement(line: str, editable: bool = False) -> Requirement:
     m = _vcs_req_re.match(line)
     r: Requirement
     if m is not None:
@@ -478,26 +493,26 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
         if replaced:
             line = line.replace("{root:uri}", root_url)
         try:
-            package_req = PackageRequirement(line)  # type: ignore
+            pkg_req = parse_as_pkg_requirement(line)
         except InvalidRequirement as e:
             m = _file_req_re.match(line)
             if m is None:
                 raise RequirementError(str(e)) from None
-            r = FileRequirement.create(**m.groupdict())
+            args = m.groupdict()
+            if not line.startswith(".") and not args["url"] and args["path"] and not os.path.exists(args["path"]):
+                raise RequirementError(str(e)) from None
+            r = FileRequirement.create(**args)
         else:
-            r = Requirement.from_pkg_requirement(package_req)
+            r = Requirement.from_pkg_requirement(pkg_req)
         if replaced:
             assert isinstance(r, FileRequirement)
             r.url = r.url.replace(root_url, "{root:uri}")
             r.path = Path(get_relative_path(r.url) or "")
 
     if editable:
-        if r.is_vcs or r.is_file_or_url and r.is_local_dir:  # type: ignore
+        if r.is_vcs or r.is_file_or_url and r.is_local_dir:  # type: ignore[attr-defined]
             assert isinstance(r, FileRequirement)
             r.editable = True
         else:
-            raise RequirementError(
-                "Editable requirement is only supported for VCS link"
-                " or local directory."
-            )
+            raise RequirementError("Editable requirement is only supported for VCS link or local directory.")
     return r
