@@ -3,7 +3,6 @@ import shutil
 import pytest
 from unearth import Link
 
-from pdm.cli import actions
 from pdm.models.requirements import parse_requirement
 from pdm.models.specifiers import PySpecSet
 from pdm.utils import path_to_url
@@ -26,7 +25,7 @@ def test_add_package(project, working_set, dev_option, pdm):
 
 
 def test_add_command(project, pdm, mocker):
-    do_add = mocker.patch.object(actions, "do_add")
+    do_add = mocker.patch("pdm.cli.commands.add.Command.do_add")
     pdm(["add", "requests"], obj=project)
     do_add.assert_called_once()
 
@@ -86,7 +85,7 @@ def test_non_editable_override_editable(project, pdm):
     url = "git+https://github.com/test-root/demo.git#egg=demo"
     pdm(["add", "--dev", "-e", url], obj=project, strict=True)
     pdm(["add", "--dev", url], obj=project, strict=True)
-    assert not project.dev_dependencies["demo"].editable
+    assert not project.get_dependencies("dev")["demo"].editable
 
 
 @pytest.mark.usefixtures("working_set")
@@ -257,7 +256,7 @@ def test_add_editable_package_with_extras(project, working_set, pdm):
     project.environment.python_requires = PySpecSet(">=3.6")
     dep_path = FIXTURES.joinpath("projects/demo").as_posix()
     pdm(["add", "-dGdev", "-e", f"{dep_path}[security]"], obj=project, strict=True)
-    assert f"-e {path_to_url(dep_path)}#egg=demo[security]" in project.get_pyproject_dependencies("dev", True)[0]
+    assert f"-e {path_to_url(dep_path)}#egg=demo[security]" in project.use_pyproject_dependencies("dev", True)[0]
     assert "demo" in working_set
     assert "requests" in working_set
     assert "urllib3" in working_set
@@ -267,7 +266,7 @@ def test_add_package_with_local_version(project, repository, working_set, pdm):
     repository.add_candidate("foo", "1.0-alpha.0+local")
     pdm(["add", "foo"], obj=project, strict=True)
     assert working_set["foo"].version == "1.0-alpha.0+local"
-    dependencies, _ = project.get_pyproject_dependencies("default")
+    dependencies, _ = project.use_pyproject_dependencies("default")
     assert dependencies[0] == "foo>=1.0a0"
 
 
