@@ -124,7 +124,7 @@ def test_sync_with_index_change(project, index, pdm):
     </html>
     """
     pdm(["lock"], obj=project, strict=True)
-    file_hashes = project.lockfile["metadata"]["files"]["future-fstrings 1.2.0"]
+    file_hashes = project.lockfile["package"][0]["files"]
     assert [e["hash"] for e in file_hashes] == [
         "sha256:90e49598b553d8746c4dc7d9442e0359d038c3039d802c91c0a55505da318c63"
     ]
