@@ -1,3 +1,4 @@
+import json
 from pathlib import Path
 
 import pytest
@@ -10,8 +11,10 @@ from tests import FIXTURES
 
 @pytest.mark.usefixtures("project_no_init", "local_finder")
 def test_build_distributions(tmp_path, core):
+    from pdm.cli.commands.build import Command
+
     project = core.create_project()
-    actions.do_build(project, dest=tmp_path.as_posix())
+    Command.do_build(project, dest=tmp_path.as_posix())
     wheel = next(tmp_path.glob("*.whl"))
     assert wheel.name.startswith("pdm-")
     tarball = next(tmp_path.glob("*.tar.gz"))
@@ -50,6 +53,19 @@ def test_info_command(project, pdm):
     assert result.exit_code == 0
 
 
+def test_info_command_json(project, pdm):
+    result = pdm(["info", "--json"], obj=project, strict=True)
+
+    data = json.loads(result.outputs)
+
+    assert data["pdm"]["version"] == project.core.version
+    assert data["python"]["version"] == project.environment.interpreter.identifier
+    assert data["python"]["interpreter"] == str(project.environment.interpreter.executable)
+    assert isinstance(data["python"]["markers"], dict)
+    assert data["project"]["root"] == str(project.root)
+    assert isinstance(data["project"]["pypackages"], str)
+
+
 def test_info_global_project(pdm, tmp_path):
     with cd(tmp_path):
         result = pdm(["info", "-g", "--where"])
@@ -146,7 +162,7 @@ def test_show_self_package(project, pdm):
 
     result = pdm(["show", "--name", "--version"], obj=project)
     assert result.exit_code == 0
-    assert "test_project\n0.0.0\n" == result.output
+    assert "test-project\n0.0.0\n" == result.output
 
 
 def test_export_to_requirements_txt(pdm, fixture_project):
