@@ -1,6 +1,5 @@
 import pytest
 
-from pdm.cli import actions
 from pdm.models.requirements import parse_requirement
 
 
@@ -12,7 +11,7 @@ def test_update_packages_with_top(project, pdm):
 
 
 def test_update_command(project, pdm, mocker):
-    do_update = mocker.patch.object(actions, "do_update")
+    do_update = mocker.patch("pdm.cli.commands.update.Command.do_update")
     pdm(["update"], obj=project)
     do_update.assert_called_once()
 
@@ -155,8 +154,9 @@ def test_update_specified_packages_eager_mode(project, repository, pdm):
 
 @pytest.mark.usefixtures("working_set")
 def test_update_with_package_and_groups_argument(project, pdm):
-    pdm(["add", "requests", "pytz"], obj=project, strict=True)
-    result = pdm(["update", "requests", "--group", "dev"], obj=project)
+    pdm(["add", "-G", "web", "requests"], obj=project, strict=True)
+    pdm(["add", "-Gextra", "pytz"], obj=project, strict=True)
+    result = pdm(["update", "requests", "--group", "web", "-G", "extra"], obj=project)
     assert "PdmUsageError" in result.stderr
 
     result = pdm(["update", "requests", "--no-default"], obj=project)
