@@ -12,7 +12,7 @@ from unearth.vcs import Git, vcs_support
 from tests import FIXTURES
 
 if TYPE_CHECKING:
-    from pdm.pytest import IndexesDefinition, PDMCallable
+    from pdm.pytest import IndexesDefinition
 
 
 os.environ.update(CI="1", PDM_CHECK_UPDATE="0")
@@ -72,7 +72,7 @@ def build_env_wheels() -> Iterable[Path]:
             "setuptools-65.4.1-py3-none-any.whl",
             "wheel-0.37.1-py2.py3-none-any.whl",
             "flit_core-3.6.0-py3-none-any.whl",
-            "pdm_backend-2.0.2-py3-none-any.whl",
+            "pdm_backend-2.1.4-py3-none-any.whl",
             "importlib_metadata-4.8.3-py3-none-any.whl",
             "zipp-3.7.0-py3-none-any.whl",
             "typing_extensions-4.4.0-py3-none-any.whl",
@@ -81,7 +81,7 @@ def build_env_wheels() -> Iterable[Path]:
 
 
 @pytest.fixture
-def local_finder_artifacts() -> Path():
+def local_finder_artifacts() -> Path:
     return FIXTURES / "artifacts"
 
 
@@ -123,8 +123,3 @@ def is_editable(request):
 @pytest.fixture(params=[False, True])
 def dev_option(request) -> Iterable[str]:
     return ("--dev",) if request.param else ()
-
-
-@pytest.fixture
-def invoke(pdm: PDMCallable) -> PDMCallable:
-    return pdm
