@@ -210,7 +210,8 @@ def test_vcs_candidate_in_subdirectory(project, is_editable):
     candidate = Candidate(req)
     expected_deps = ["django"]
     assert candidate.prepare(project.environment).get_dependencies_from_metadata() == expected_deps
-    assert candidate.version == "0.1.0"
+    tail = "+editable" if is_editable else ""
+    assert candidate.version == f"0.1.0{tail}"
 
 
 @pytest.mark.usefixtures("local_finder")
@@ -289,6 +290,7 @@ def test_legacy_pep345_tag_link(project):
     assert candidate.requires_python == ">=3,<4"
 
 
+@pytest.mark.filterwarnings("ignore::FutureWarning")
 def test_ignore_invalid_py_version(project):
     project.project_config["pypi.url"] = "https://my.pypi.org/simple"
     req = parse_requirement("wheel")
@@ -301,6 +303,8 @@ def test_find_candidates_from_find_links(project):
     repo = project.get_repository()
     repo.sources = [
         RepositoryConfig(
+            name="test",
+            config_prefix="pypi",
             url="http://fixtures.test/index/demo.html",
             verify_ssl=False,
             type="find_links",
@@ -326,3 +330,10 @@ def test_parse_metadata_with_dynamic_fields(project, local_finder):
     metadata = candidate.prepare(project.environment).metadata
     assert not metadata.requires
     assert metadata.version == "0.1.0"
+
+
+def test_get_metadata_for_non_existing_path(project):
+    req = parse_requirement("file:///${PROJECT_ROOT}/non-existing-path")
+    candidate = Candidate(req)
+    with pytest.raises(FileNotFoundError, match="No such file or directory"):
+        candidate.prepare(project.environment).metadata
