@@ -97,7 +97,7 @@ def test_uninstall_with_console_scripts(project, use_install_cache):
     assert not os.path.exists(celery_script)
 
 
-def test_install_wheel_with_cache(project, invoke):
+def test_install_wheel_with_cache(project, pdm):
     supports_symlink = fs_supports_symlink()
     req = parse_requirement("future-fstrings")
     candidate = Candidate(
@@ -117,8 +117,8 @@ def test_install_wheel_with_cache(project, invoke):
 
     cache_path = project.cache("packages") / "future_fstrings-1.2.0-py2.py3-none-any"
     assert cache_path.is_dir()
-    invoke(["run", "python", "-m", "site"], object=project)
-    r = invoke(["run", "python", "-c", "import future_fstrings"], obj=project)
+    pdm(["run", "python", "-m", "site"], object=project)
+    r = pdm(["run", "python", "-c", "import future_fstrings"], obj=project)
     assert r.exit_code == 0
 
     dist = project.environment.get_working_set()["future-fstrings"]
