@@ -5,10 +5,11 @@ from pathlib import Path
 
 import pytest
 from packaging.version import parse
+from pytest_httpserver import HTTPServer
 
-from pdm.cli.commands.venv.utils import get_venv_python
 from pdm.environments import PythonEnvironment
 from pdm.exceptions import PdmException
+from pdm.models.venv import get_venv_python
 from pdm.utils import cd
 
 
@@ -112,7 +113,7 @@ def test_project_use_venv(project):
     project._python = None
     scripts = "Scripts" if os.name == "nt" else "bin"
     suffix = ".exe" if os.name == "nt" else ""
-    venv.create(project.root / "venv")
+    venv.create(project.root / "venv", symlinks=True)
 
     project.project_config["python.use_venv"] = True
     env = project.environment
@@ -148,7 +149,7 @@ def test_ignore_saved_python(project, monkeypatch):
     project._python = None
     scripts = "Scripts" if os.name == "nt" else "bin"
     suffix = ".exe" if os.name == "nt" else ""
-    venv.create(project.root / "venv")
+    venv.create(project.root / "venv", symlinks=True)
     monkeypatch.setenv("PDM_IGNORE_SAVED_PYTHON", "1")
     assert project.python.executable != project._saved_python
     assert project.python.executable == project.root / "venv" / scripts / f"python{suffix}"
@@ -165,11 +166,9 @@ def test_select_dependencies(project):
         "doc": ["mkdocs"],
     }
     assert sorted(project.get_dependencies()) == ["requests"]
-    assert sorted(project.dependencies) == ["requests"]
 
     assert sorted(project.get_dependencies("security")) == ["cryptography"]
     assert sorted(project.get_dependencies("test")) == ["pytest"]
-    assert sorted(project.dev_dependencies) == ["mkdocs", "pytest"]
 
     assert sorted(project.iter_groups()) == [
         "default",
@@ -188,10 +187,10 @@ def test_set_non_exist_python_path(project_no_init):
 
 
 @pytest.mark.usefixtures("venv_backends")
-def test_create_venv_first_time(invoke, project, local_finder):
+def test_create_venv_first_time(pdm, project, local_finder):
     project.project_config.update({"venv.in_project": False})
     project._saved_python = None
-    result = invoke(["install"], obj=project)
+    result = pdm(["install"], obj=project)
     assert result.exit_code == 0
     venv_parent = project.root / "venvs"
     venv_path = next(venv_parent.iterdir(), None)
@@ -202,10 +201,10 @@ def test_create_venv_first_time(invoke, project, local_finder):
 
 @pytest.mark.usefixtures("venv_backends", "local_finder")
 @pytest.mark.parametrize("with_pip", [True, False])
-def test_create_venv_in_project(invoke, project, with_pip):
+def test_create_venv_in_project(pdm, project, with_pip):
     project.project_config.update({"venv.in_project": True, "venv.with_pip": with_pip})
     project._saved_python = None
-    result = invoke(["install"], obj=project)
+    result = pdm(["install"], obj=project)
     assert result.exit_code == 0
     assert project.root.joinpath(".venv").exists()
     working_set = project.environment.get_working_set()
@@ -213,10 +212,10 @@ def test_create_venv_in_project(invoke, project, with_pip):
 
 
 @pytest.mark.usefixtures("venv_backends")
-def test_find_interpreters_from_venv(invoke, project, local_finder):
+def test_find_interpreters_from_venv(pdm, project, local_finder):
     project.project_config.update({"venv.in_project": False})
     project._saved_python = None
-    result = invoke(["install"], obj=project)
+    result = pdm(["install"], obj=project)
     assert result.exit_code == 0
     venv_parent = project.root / "venvs"
     venv_path = next(venv_parent.iterdir(), None)
@@ -226,7 +225,7 @@ def test_find_interpreters_from_venv(invoke, project, local_finder):
 
 
 @pytest.mark.usefixtures("local_finder")
-def test_find_interpreters_without_duplicate_relative_paths(invoke, project):
+def test_find_interpreters_without_duplicate_relative_paths(pdm, project):
     project._saved_python = None
     venv.create(project.root / ".venv", clear=True)
     with cd(project.root):
@@ -237,16 +236,19 @@ def test_find_interpreters_without_duplicate_relative_paths(invoke, project):
 
 
 def test_iter_project_venvs(project):
-    from pdm.cli.commands.venv import utils
+    from pdm.cli.commands.venv.utils import get_venv_prefix, iter_venvs
+    from pdm.models.venv import get_venv_python
 
     venv_parent = Path(project.config["venv.location"])
-    venv_prefix = utils.get_venv_prefix(project)
+    venv_prefix = get_venv_prefix(project)
     for name in ("foo", "bar", "baz"):
-        venv_parent.joinpath(venv_prefix + name).mkdir(parents=True)
-    dot_venv_python = utils.get_venv_python(project.root / ".venv")
+        venv_python = get_venv_python(venv_parent / (venv_prefix + name))
+        venv_python.parent.mkdir(parents=True)
+        venv_python.touch()
+    dot_venv_python = get_venv_python(project.root / ".venv")
     dot_venv_python.parent.mkdir(parents=True)
     dot_venv_python.touch()
-    venv_keys = [key for key, _ in utils.iter_venvs(project)]
+    venv_keys = [key for key, _ in iter_venvs(project)]
     assert sorted(venv_keys) == ["bar", "baz", "foo", "in-project"]
 
 
@@ -275,19 +277,20 @@ def test_no_index_raise_error(project):
             pass
 
 
-@pytest.mark.network
-def test_access_index_with_auth(project):
-    url = "https://httpbin.org/basic-auth/foo/bar"
+def test_access_index_with_auth(project, httpserver: HTTPServer):
+    httpserver.expect_request(
+        "/simple/my-package", method="GET", headers={"Authorization": "Basic Zm9vOmJhcg=="}
+    ).respond_with_data("OK")
     project.global_config.update(
         {
-            "pypi.extra.url": "https://httpbin.org",
+            "pypi.extra.url": httpserver.url_for("/simple"),
             "pypi.extra.username": "foo",
             "pypi.extra.password": "bar",
         }
     )
     with project.environment.get_finder() as finder:
         session = finder.session
-        resp = session.get(url)
+        resp = session.get(httpserver.url_for("/simple/my-package"))
         assert resp.ok
 
 
@@ -309,3 +312,19 @@ def test_configured_source_overwriting(project):
     assert custom_source.verify_ssl is False
     assert custom_source.username == "foo"
     assert custom_source.password == "bar"
+
+
+def test_invoke_pdm_adding_configured_args(project, pdm, mocker):
+    project.pyproject.settings["options"] = {
+        "install": ["--no-self", "--no-editable"],
+        "add": ["--no-isolation"],
+        "lock": ["--no-cross-platform"],
+    }
+    project.pyproject.write()
+    parser = mocker.patch("argparse.ArgumentParser.parse_args")
+    pdm(["add", "requests"], obj=project)
+    parser.assert_called_with(["add", "--no-isolation", "requests"])
+    pdm(["install", "--check"], obj=project)
+    parser.assert_called_with(["install", "--no-self", "--no-editable", "--check"])
+    pdm(["lock", "--lockfile", "pdm.2.lock"], obj=project)
+    parser.assert_called_with(["lock", "--no-cross-platform", "--lockfile", "pdm.2.lock"])
