@@ -5,10 +5,10 @@ import pytest
 from pdm import signals
 
 
-def test_post_init_signal(project_no_init, invoke):
+def test_post_init_signal(project_no_init, pdm):
     mock_handler = mock.Mock()
     with signals.post_init.connected_to(mock_handler):
-        result = invoke(["init"], input="\n\n\n\n\n\n", obj=project_no_init)
+        result = pdm(["init"], input="\n\n\n\n\n\n", obj=project_no_init)
         assert result.exit_code == 0
     mock_handler.assert_called_once_with(project_no_init, hooks=mock.ANY)
 
