@@ -2,6 +2,8 @@ import pathlib
 import sys
 
 import pytest
+import tomlkit
+from packaging.version import Version
 
 from pdm import utils
 from pdm.cli import utils as cli_utils
@@ -68,10 +70,12 @@ def test_find_python_in_path(tmp_path):
 
 
 def test_merge_dictionary():
-    target = {
-        "existing_dict": {"foo": "bar", "hello": "world"},
-        "existing_list": ["hello"],
-    }
+    target = tomlkit.item(
+        {
+            "existing_dict": {"foo": "bar", "hello": "world"},
+            "existing_list": ["hello"],
+        }
+    )
     input_dict = {
         "existing_dict": {"foo": "baz"},
         "existing_list": ["world"],
@@ -135,10 +139,15 @@ def test_prod_should_not_be_with_dev(project):
 
 
 def test_deprecation_warning():
-    with pytest.warns(DeprecationWarning) as record:
+    with pytest.warns(FutureWarning) as record:
         utils.deprecation_warning("Test warning", raise_since="99.99")
     assert len(record) == 1
     assert str(record[0].message) == "Test warning"
 
-    with pytest.raises(DeprecationWarning):
+    with pytest.raises(FutureWarning):
         utils.deprecation_warning("Test warning", raise_since="0.0")
+
+
+def test_comparable_version():
+    assert utils.comparable_version("1.2.3") == Version("1.2.3")
+    assert utils.comparable_version("1.2.3a1+local1") == Version("1.2.3a1")
